#[repr(C)]pub struct MTLAccelerationStructureMotionTriangleGeometryDescriptor { /* private fields */ }Available on crate feature
MTLAccelerationStructure only.Implementations
sourceimpl MTLAccelerationStructureMotionTriangleGeometryDescriptor
impl MTLAccelerationStructureMotionTriangleGeometryDescriptor
pub unsafe fn vertexBuffers(&self) -> Retained<NSArray<MTLMotionKeyframeData>>
pub unsafe fn setVertexBuffers( &self, vertex_buffers: &NSArray<MTLMotionKeyframeData> )
pub unsafe fn vertexFormat(&self) -> MTLAttributeFormat
Available on crate feature
MTLStageInputOutputDescriptor only.pub unsafe fn setVertexFormat(&self, vertex_format: MTLAttributeFormat)
Available on crate feature
MTLStageInputOutputDescriptor only.pub unsafe fn vertexStride(&self) -> NSUInteger
pub unsafe fn setVertexStride(&self, vertex_stride: NSUInteger)
pub unsafe fn indexBuffer( &self ) -> Option<Retained<ProtocolObject<dyn MTLBuffer>>>
Available on crate features
MTLBuffer and MTLResource only.pub unsafe fn setIndexBuffer( &self, index_buffer: Option<&ProtocolObject<dyn MTLBuffer>> )
Available on crate features
MTLBuffer and MTLResource only.pub unsafe fn indexBufferOffset(&self) -> NSUInteger
pub unsafe fn setIndexBufferOffset(&self, index_buffer_offset: NSUInteger)
pub unsafe fn indexType(&self) -> MTLIndexType
Available on crate feature
MTLStageInputOutputDescriptor only.pub unsafe fn setIndexType(&self, index_type: MTLIndexType)
Available on crate feature
MTLStageInputOutputDescriptor only.pub unsafe fn triangleCount(&self) -> NSUInteger
pub unsafe fn setTriangleCount(&self, triangle_count: NSUInteger)
pub unsafe fn transformationMatrixBuffer( &self ) -> Option<Retained<ProtocolObject<dyn MTLBuffer>>>
Available on crate features
MTLBuffer and MTLResource only.pub unsafe fn setTransformationMatrixBuffer( &self, transformation_matrix_buffer: Option<&ProtocolObject<dyn MTLBuffer>> )
Available on crate features
MTLBuffer and MTLResource only.pub unsafe fn transformationMatrixBufferOffset(&self) -> NSUInteger
pub unsafe fn setTransformationMatrixBufferOffset( &self, transformation_matrix_buffer_offset: NSUInteger )
pub unsafe fn descriptor() -> Retained<Self>
Methods from Deref<Target = MTLAccelerationStructureGeometryDescriptor>
pub unsafe fn intersectionFunctionTableOffset(&self) -> NSUInteger
pub fn setIntersectionFunctionTableOffset( &self, intersection_function_table_offset: NSUInteger )
pub unsafe fn opaque(&self) -> bool
pub unsafe fn setOpaque(&self, opaque: bool)
pub unsafe fn allowDuplicateIntersectionFunctionInvocation(&self) -> bool
pub unsafe fn setAllowDuplicateIntersectionFunctionInvocation( &self, allow_duplicate_intersection_function_invocation: bool )
pub unsafe fn label(&self) -> Option<Retained<NSString>>
pub unsafe fn setLabel(&self, label: Option<&NSString>)
pub unsafe fn primitiveDataBuffer( &self ) -> Option<Retained<ProtocolObject<dyn MTLBuffer>>>
Available on crate features
MTLBuffer and MTLResource only.pub fn setPrimitiveDataBuffer( &self, primitive_data_buffer: Option<&ProtocolObject<dyn MTLBuffer>> )
Available on crate features
MTLBuffer and MTLResource only.pub unsafe fn primitiveDataBufferOffset(&self) -> NSUInteger
pub unsafe fn setPrimitiveDataBufferOffset( &self, primitive_data_buffer_offset: NSUInteger )
pub unsafe fn primitiveDataStride(&self) -> NSUInteger
pub fn setPrimitiveDataStride(&self, primitive_data_stride: NSUInteger)
pub unsafe fn primitiveDataElementSize(&self) -> NSUInteger
pub fn setPrimitiveDataElementSize( &self, primitive_data_element_size: NSUInteger )
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.