Struct objc2_metal::MTLArgumentDescriptor
source · #[repr(C)]pub struct MTLArgumentDescriptor { /* private fields */ }Available on crate feature
MTLDevice only.Implementations
sourceimpl MTLArgumentDescriptor
impl MTLArgumentDescriptor
pub fn argumentDescriptor() -> Retained<MTLArgumentDescriptor>
pub unsafe fn dataType(&self) -> MTLDataType
Available on crate feature
MTLArgument only.pub fn setDataType(&self, data_type: MTLDataType)
Available on crate feature
MTLArgument only.pub unsafe fn index(&self) -> NSUInteger
pub fn setIndex(&self, index: NSUInteger)
pub unsafe fn arrayLength(&self) -> NSUInteger
pub unsafe fn setArrayLength(&self, array_length: NSUInteger)
pub unsafe fn access(&self) -> MTLBindingAccess
Available on crate feature
MTLArgument only.pub fn setAccess(&self, access: MTLBindingAccess)
Available on crate feature
MTLArgument only.pub unsafe fn textureType(&self) -> MTLTextureType
Available on crate feature
MTLTexture only.pub fn setTextureType(&self, texture_type: MTLTextureType)
Available on crate feature
MTLTexture only.pub unsafe fn constantBlockAlignment(&self) -> NSUInteger
pub unsafe fn setConstantBlockAlignment( &self, constant_block_alignment: NSUInteger )
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.