#[repr(C)]pub struct MTLComputePassSampleBufferAttachmentDescriptor { /* private fields */ }Available on crate feature
MTLComputePass only.Implementations
sourceimpl MTLComputePassSampleBufferAttachmentDescriptor
impl MTLComputePassSampleBufferAttachmentDescriptor
pub unsafe fn sampleBuffer( &self ) -> Option<Retained<ProtocolObject<dyn MTLCounterSampleBuffer>>>
Available on crate feature
MTLCounters only.pub unsafe fn setSampleBuffer( &self, sample_buffer: Option<&ProtocolObject<dyn MTLCounterSampleBuffer>> )
Available on crate feature
MTLCounters only.pub unsafe fn startOfEncoderSampleIndex(&self) -> NSUInteger
pub unsafe fn setStartOfEncoderSampleIndex( &self, start_of_encoder_sample_index: NSUInteger )
pub unsafe fn endOfEncoderSampleIndex(&self) -> NSUInteger
pub unsafe fn setEndOfEncoderSampleIndex( &self, end_of_encoder_sample_index: NSUInteger )
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.