#[repr(C)]pub struct MTLComputePipelineDescriptor { /* private fields */ }Available on crate feature
MTLComputePipeline only.Implementations
sourceimpl MTLComputePipelineDescriptor
impl MTLComputePipelineDescriptor
pub fn label(&self) -> Option<Retained<NSString>>
pub fn setLabel(&self, label: Option<&NSString>)
pub fn computeFunction( &self ) -> Option<Retained<ProtocolObject<dyn MTLFunction>>>
Available on crate feature
MTLLibrary only.pub fn setComputeFunction( &self, compute_function: Option<&ProtocolObject<dyn MTLFunction>> )
Available on crate feature
MTLLibrary only.pub fn threadGroupSizeIsMultipleOfThreadExecutionWidth(&self) -> bool
pub unsafe fn setThreadGroupSizeIsMultipleOfThreadExecutionWidth( &self, thread_group_size_is_multiple_of_thread_execution_width: bool )
pub fn maxTotalThreadsPerThreadgroup(&self) -> NSUInteger
pub fn setMaxTotalThreadsPerThreadgroup( &self, max_total_threads_per_threadgroup: NSUInteger )
pub fn stageInputDescriptor( &self ) -> Option<Retained<MTLStageInputOutputDescriptor>>
Available on crate feature
MTLStageInputOutputDescriptor only.pub fn setStageInputDescriptor( &self, stage_input_descriptor: Option<&MTLStageInputOutputDescriptor> )
Available on crate feature
MTLStageInputOutputDescriptor only.pub fn buffers(&self) -> Retained<MTLPipelineBufferDescriptorArray>
Available on crate feature
MTLPipeline only.pub fn supportIndirectCommandBuffers(&self) -> bool
pub fn setSupportIndirectCommandBuffers( &self, support_indirect_command_buffers: bool )
pub fn insertLibraries( &self ) -> Option<Retained<NSArray<ProtocolObject<dyn MTLDynamicLibrary>>>>
👎Deprecated
Available on crate feature
MTLDynamicLibrary only.pub fn setInsertLibraries( &self, insert_libraries: Option<&NSArray<ProtocolObject<dyn MTLDynamicLibrary>>> )
👎Deprecated
Available on crate feature
MTLDynamicLibrary only.pub fn preloadedLibraries( &self ) -> Retained<NSArray<ProtocolObject<dyn MTLDynamicLibrary>>>
Available on crate feature
MTLDynamicLibrary only.pub fn setPreloadedLibraries( &self, preloaded_libraries: &NSArray<ProtocolObject<dyn MTLDynamicLibrary>> )
Available on crate feature
MTLDynamicLibrary only.pub fn binaryArchives( &self ) -> Option<Retained<NSArray<ProtocolObject<dyn MTLBinaryArchive>>>>
Available on crate feature
MTLBinaryArchive only.pub fn setBinaryArchives( &self, binary_archives: Option<&NSArray<ProtocolObject<dyn MTLBinaryArchive>>> )
Available on crate feature
MTLBinaryArchive only.pub fn reset(&self)
pub fn linkedFunctions(&self) -> Option<Retained<MTLLinkedFunctions>>
Available on crate feature
MTLLinkedFunctions only.pub fn setLinkedFunctions(&self, linked_functions: Option<&MTLLinkedFunctions>)
Available on crate feature
MTLLinkedFunctions only.pub fn supportAddingBinaryFunctions(&self) -> bool
pub fn setSupportAddingBinaryFunctions( &self, support_adding_binary_functions: bool )
pub fn maxCallStackDepth(&self) -> NSUInteger
pub fn setMaxCallStackDepth(&self, max_call_stack_depth: NSUInteger)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.