#[repr(transparent)]pub struct MTLDataType(pub NSUInteger);MTLDataType only.Expand description
An enumeration of the different data types in Metal.
See also Apple’s documentation
Tuple Fields
0: NSUIntegerImplementations
Sourceimpl MTLDataType
impl MTLDataType
Sourcepub const Float2: Self
pub const Float2: Self
Represents a data type consisting of a vector of two floating-point values.
Sourcepub const Float3: Self
pub const Float3: Self
Represents a data type consisting of a vector of three floating-point values.
Sourcepub const Float4: Self
pub const Float4: Self
Represents a data type consisting of a vector of four floating-point values.
Sourcepub const Half: Self
pub const Half: Self
Represents a data type consisting of a half-precision floating-point value.
Sourcepub const Half2: Self
pub const Half2: Self
Represents a data type consisting of a vector of two half-precision floating-point values.
Sourcepub const Half3: Self
pub const Half3: Self
Represents a data type consisting of a vector of three half-precision floating-point values.
Sourcepub const Half4: Self
pub const Half4: Self
Represents a data type consisting of a vector of four half-precision floating-point values.
Sourcepub const Half2x2: Self
pub const Half2x2: Self
Represents a data type consisting of a 2x2 half-precision floating-point matrix.
Sourcepub const Half2x3: Self
pub const Half2x3: Self
Represents a data type consisting of a 2x3 half-precision floating-point matrix.
Sourcepub const Half2x4: Self
pub const Half2x4: Self
Represents a data type consisting of a 2x4 half-precision floating-point matrix.
Sourcepub const Half3x2: Self
pub const Half3x2: Self
Represents a data type consisting of a 3x2 half-precision floating-point matrix.
Sourcepub const Half3x3: Self
pub const Half3x3: Self
Represents a data type consisting of a 3x3 half-precision floating-point matrix.
Sourcepub const Half3x4: Self
pub const Half3x4: Self
Represents a data type consisting of a 3x4 half-precision floating-point matrix.
Sourcepub const Half4x2: Self
pub const Half4x2: Self
Represents a data type consisting of a 4x2 half-precision floating-point matrix.
Sourcepub const Half4x3: Self
pub const Half4x3: Self
Represents a data type consisting of a 4x3 half-precision floating-point matrix.
Sourcepub const Half4x4: Self
pub const Half4x4: Self
Represents a data type consisting of a 4x4 half-precision floating-point matrix.
Sourcepub const Int2: Self
pub const Int2: Self
Represents a data type consisting of a vector of two signed integer values.
Sourcepub const Int3: Self
pub const Int3: Self
Represents a data type consisting of a vector of three signed integer values.
Sourcepub const Int4: Self
pub const Int4: Self
Represents a data type consisting of a vector of four signed integer values.
Sourcepub const UInt2: Self
pub const UInt2: Self
Represents a data type consisting of a vector of two unsigned integer values.
Sourcepub const UInt3: Self
pub const UInt3: Self
Represents a data type consisting of a vector of three unsigned integer values.
Sourcepub const UInt4: Self
pub const UInt4: Self
Represents a data type consisting of a vector of four unsigned integer values.
Sourcepub const Short: Self
pub const Short: Self
Represents a data type consisting of a single 16-bit signed integer value.
Sourcepub const Short2: Self
pub const Short2: Self
Represents a data type consisting of a vector of two 16-bit signed integer values.
Sourcepub const Short3: Self
pub const Short3: Self
Represents a data type consisting of a vector of three 16-bit signed integer values.
Sourcepub const Short4: Self
pub const Short4: Self
Represents a data type consisting of a vector of three 16-bit signed integer values.
Sourcepub const UShort: Self
pub const UShort: Self
Represents a data type consisting of a single 16-bit unsigned integer value.
Sourcepub const UShort2: Self
pub const UShort2: Self
Represents a data type consisting of a vector of two 16-bit unsigned integer values.
Sourcepub const UShort3: Self
pub const UShort3: Self
Represents a data type consisting of a vector of three 16-bit unsigned integer values.
Sourcepub const UShort4: Self
pub const UShort4: Self
Represents a data type consisting of a vector of four 16-bit unsigned integer values.
Sourcepub const Char2: Self
pub const Char2: Self
Represents a data type consisting of a vector of two signed character values.
Sourcepub const Char3: Self
pub const Char3: Self
Represents a data type consisting of a vector of three signed character values.
Sourcepub const Char4: Self
pub const Char4: Self
Represents a data type consisting of a vector of four signed character values.
Sourcepub const UChar2: Self
pub const UChar2: Self
Represents a data type consisting of a vector of two unsigned character values.
Sourcepub const UChar3: Self
pub const UChar3: Self
Represents a data type consisting of a vector of three unsigned character values.
Sourcepub const UChar4: Self
pub const UChar4: Self
Represents a data type consisting of a vector of four unsigned character values.
Sourcepub const R8Unorm: Self
pub const R8Unorm: Self
Represents an image block data type consisting of an unsigned 8-bit red channel normalized to the [0-1] range.
Sourcepub const R8Snorm: Self
pub const R8Snorm: Self
Represents an image block data type consisting of an signed 8-bit red channel normalized to the [0-1] range.
Sourcepub const R16Unorm: Self
pub const R16Unorm: Self
Represents an image block data type consisting of an unsigned 16-bit red channel normalized to the [0-1] range.
Sourcepub const R16Snorm: Self
pub const R16Snorm: Self
Represents an image block data type consisting of a signed 16-bit red channel normalized to the [0-1] range.
Sourcepub const RG8Unorm: Self
pub const RG8Unorm: Self
Represents an image block data type consisting of an unsigned 8-bit red channel and a unsigned 8-bit green channel, both normalized to the [0-1] range.
Sourcepub const RG8Snorm: Self
pub const RG8Snorm: Self
Represents an image block data type consisting of a signed 8-bit red channel and a signed 8-bit green channel, both normalized to the [0-1] range.
Sourcepub const RG16Unorm: Self
pub const RG16Unorm: Self
Represents an image block data type consisting of an unsigned 16-bit red channel and an unsigned 16-bit green channel, both normalized to the [0-1] range.
Sourcepub const RG16Snorm: Self
pub const RG16Snorm: Self
Represents an image block data type consisting of a signed 16-bit red channel and a signed 16-bit green channel, both normalized to the [0-1] range.
Sourcepub const RGBA8Unorm: Self
pub const RGBA8Unorm: Self
Represents an image block data type consisting of four unsigned 8-bit channels normalized to the [0-1] range.
Sourcepub const RGBA8Unorm_sRGB: Self
pub const RGBA8Unorm_sRGB: Self
Represents an image block data type consisting of four unsigned 8-bit channels normalized to the [0-1] range and subject to gamma-correction.
Sourcepub const RGBA8Snorm: Self
pub const RGBA8Snorm: Self
Represents an image block data type consisting of four signed 8-bit channels normalized to the [0-1] range.
Sourcepub const RGBA16Unorm: Self
pub const RGBA16Unorm: Self
Represents an image block data type consisting of four unsigned 16-bit channels normalized to the [0-1] range.
Sourcepub const RGBA16Snorm: Self
pub const RGBA16Snorm: Self
Represents an image block data type consisting of four signed 16-bit channels normalized to the [0-1] range.
Sourcepub const RGB10A2Unorm: Self
pub const RGB10A2Unorm: Self
Represents an image block data type consisting of three unsigned 10-bit channels and one 2-bit unsigned alpha channel, all normalized to the [0-1] range.
Sourcepub const RG11B10Float: Self
pub const RG11B10Float: Self
Represents an image block data type consisting of two 11-bit floating-point channels, and one 10-bit floating-point blue channel.
Sourcepub const RGB9E5Float: Self
pub const RGB9E5Float: Self
Represents an image block data type consisting of three 9-bit floating-point channels, and one 5-bit floating-point exponent.
Sourcepub const RenderPipeline: Self
pub const RenderPipeline: Self
Represents a data type corresponding to a render pipeline state object.
Sourcepub const ComputePipeline: Self
pub const ComputePipeline: Self
Represents a data type corresponding to a compute pipeline state object.
Sourcepub const IndirectCommandBuffer: Self
pub const IndirectCommandBuffer: Self
Represents a data type corresponding to an indirect command buffer object.
Sourcepub const Long2: Self
pub const Long2: Self
Represents a data type consisting of a vector of two signed long integer values.
Sourcepub const Long3: Self
pub const Long3: Self
Represents a data type consisting of a vector of three signed long integer values.
Sourcepub const Long4: Self
pub const Long4: Self
Represents a data type consisting of a vector of four signed long integer values.
Sourcepub const ULong2: Self
pub const ULong2: Self
Represents a data type consisting of a vector two unsigned long integer values.
Sourcepub const ULong3: Self
pub const ULong3: Self
Represents a data type consisting of a vector three unsigned long integer values.
Sourcepub const ULong4: Self
pub const ULong4: Self
Represents a data type consisting of a vector four unsigned long integer values.
Sourcepub const VisibleFunctionTable: Self
pub const VisibleFunctionTable: Self
Represents a data type corresponding to a visible function table object.
Sourcepub const IntersectionFunctionTable: Self
pub const IntersectionFunctionTable: Self
Represents a data type corresponding to an intersection function table object.
Sourcepub const PrimitiveAccelerationStructure: Self
pub const PrimitiveAccelerationStructure: Self
Represents a data type corresponding to a primitive acceleration structure.
Sourcepub const InstanceAccelerationStructure: Self
pub const InstanceAccelerationStructure: Self
Represents a data type corresponding to an instance acceleration structure.
Sourcepub const DepthStencilState: Self
pub const DepthStencilState: Self
Represents a data type corresponding to a depth-stencil state object.