Struct objc2_metal::MTLDepthStencilDescriptor
source · #[repr(C)]pub struct MTLDepthStencilDescriptor { /* private fields */ }Available on crate feature
MTLDepthStencil only.Implementations
sourceimpl MTLDepthStencilDescriptor
impl MTLDepthStencilDescriptor
pub fn depthCompareFunction(&self) -> MTLCompareFunction
pub fn setDepthCompareFunction( &self, depth_compare_function: MTLCompareFunction )
pub fn isDepthWriteEnabled(&self) -> bool
pub fn setDepthWriteEnabled(&self, depth_write_enabled: bool)
pub fn frontFaceStencil(&self) -> Retained<MTLStencilDescriptor>
pub fn setFrontFaceStencil( &self, front_face_stencil: Option<&MTLStencilDescriptor> )
pub fn backFaceStencil(&self) -> Retained<MTLStencilDescriptor>
pub fn setBackFaceStencil( &self, back_face_stencil: Option<&MTLStencilDescriptor> )
pub fn label(&self) -> Option<Retained<NSString>>
pub fn setLabel(&self, label: Option<&NSString>)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.