Struct objc2_metal::MTLFunctionDescriptor
source · #[repr(C)]pub struct MTLFunctionDescriptor { /* private fields */ }Available on crate feature
MTLFunctionDescriptor only.Implementations
sourceimpl MTLFunctionDescriptor
impl MTLFunctionDescriptor
pub fn functionDescriptor() -> Retained<MTLFunctionDescriptor>
pub fn name(&self) -> Option<Retained<NSString>>
pub fn setName(&self, name: Option<&NSString>)
pub fn specializedName(&self) -> Option<Retained<NSString>>
pub fn setSpecializedName(&self, specialized_name: Option<&NSString>)
pub fn constantValues(&self) -> Option<Retained<MTLFunctionConstantValues>>
Available on crate feature
MTLFunctionConstantValues only.pub fn setConstantValues( &self, constant_values: Option<&MTLFunctionConstantValues> )
Available on crate feature
MTLFunctionConstantValues only.pub fn options(&self) -> MTLFunctionOptions
pub fn setOptions(&self, options: MTLFunctionOptions)
pub unsafe fn binaryArchives( &self ) -> Option<Retained<NSArray<ProtocolObject<dyn MTLBinaryArchive>>>>
Available on crate feature
MTLBinaryArchive only.pub unsafe fn setBinaryArchives( &self, binary_archives: Option<&NSArray<ProtocolObject<dyn MTLBinaryArchive>>> )
Available on crate feature
MTLBinaryArchive only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.