Struct objc2_metal::MTLHeapDescriptor
source · #[repr(C)]pub struct MTLHeapDescriptor { /* private fields */ }Available on crate feature
MTLHeap only.Implementations
sourceimpl MTLHeapDescriptor
impl MTLHeapDescriptor
pub fn size(&self) -> NSUInteger
pub fn setSize(&self, size: NSUInteger)
pub fn storageMode(&self) -> MTLStorageMode
Available on crate feature
MTLResource only.pub fn setStorageMode(&self, storage_mode: MTLStorageMode)
Available on crate feature
MTLResource only.pub fn cpuCacheMode(&self) -> MTLCPUCacheMode
Available on crate feature
MTLResource only.pub fn setCpuCacheMode(&self, cpu_cache_mode: MTLCPUCacheMode)
Available on crate feature
MTLResource only.pub unsafe fn sparsePageSize(&self) -> MTLSparsePageSize
Available on crate feature
MTLDevice only.pub unsafe fn setSparsePageSize(&self, sparse_page_size: MTLSparsePageSize)
Available on crate feature
MTLDevice only.pub fn hazardTrackingMode(&self) -> MTLHazardTrackingMode
Available on crate feature
MTLResource only.pub fn setHazardTrackingMode(&self, hazard_tracking_mode: MTLHazardTrackingMode)
Available on crate feature
MTLResource only.pub fn resourceOptions(&self) -> MTLResourceOptions
Available on crate feature
MTLResource only.pub fn setResourceOptions(&self, resource_options: MTLResourceOptions)
Available on crate feature
MTLResource only.pub unsafe fn type(&self) -> MTLHeapType
pub fn setType(&self, type: MTLHeapType)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.