Struct objc2_metal::MTLLinkedFunctions
source · #[repr(C)]pub struct MTLLinkedFunctions { /* private fields */ }Available on crate feature
MTLLinkedFunctions only.Implementations
sourceimpl MTLLinkedFunctions
impl MTLLinkedFunctions
pub fn linkedFunctions() -> Retained<MTLLinkedFunctions>
pub fn functions( &self ) -> Option<Retained<NSArray<ProtocolObject<dyn MTLFunction>>>>
Available on crate feature
MTLLibrary only.pub fn setFunctions( &self, functions: Option<&NSArray<ProtocolObject<dyn MTLFunction>>> )
Available on crate feature
MTLLibrary only.pub fn binaryFunctions( &self ) -> Option<Retained<NSArray<ProtocolObject<dyn MTLFunction>>>>
Available on crate feature
MTLLibrary only.pub fn setBinaryFunctions( &self, binary_functions: Option<&NSArray<ProtocolObject<dyn MTLFunction>>> )
Available on crate feature
MTLLibrary only.pub fn groups( &self ) -> Option<Retained<NSDictionary<NSString, NSArray<ProtocolObject<dyn MTLFunction>>>>>
Available on crate feature
MTLLibrary only.pub fn setGroups( &self, groups: Option<&NSDictionary<NSString, NSArray<ProtocolObject<dyn MTLFunction>>>> )
Available on crate feature
MTLLibrary only.pub fn privateFunctions( &self ) -> Option<Retained<NSArray<ProtocolObject<dyn MTLFunction>>>>
Available on crate feature
MTLLibrary only.pub fn setPrivateFunctions( &self, private_functions: Option<&NSArray<ProtocolObject<dyn MTLFunction>>> )
Available on crate feature
MTLLibrary only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.