#[repr(C)]pub struct MTLMeshRenderPipelineDescriptor { /* private fields */ }Available on crate feature
MTLRenderPipeline only.Implementations
sourceimpl MTLMeshRenderPipelineDescriptor
impl MTLMeshRenderPipelineDescriptor
pub unsafe fn label(&self) -> Option<Retained<NSString>>
pub unsafe fn setLabel(&self, label: Option<&NSString>)
pub unsafe fn objectFunction( &self ) -> Option<Retained<ProtocolObject<dyn MTLFunction>>>
Available on crate feature
MTLLibrary only.pub unsafe fn setObjectFunction( &self, object_function: Option<&ProtocolObject<dyn MTLFunction>> )
Available on crate feature
MTLLibrary only.pub unsafe fn meshFunction( &self ) -> Option<Retained<ProtocolObject<dyn MTLFunction>>>
Available on crate feature
MTLLibrary only.pub unsafe fn setMeshFunction( &self, mesh_function: Option<&ProtocolObject<dyn MTLFunction>> )
Available on crate feature
MTLLibrary only.pub unsafe fn fragmentFunction( &self ) -> Option<Retained<ProtocolObject<dyn MTLFunction>>>
Available on crate feature
MTLLibrary only.pub unsafe fn setFragmentFunction( &self, fragment_function: Option<&ProtocolObject<dyn MTLFunction>> )
Available on crate feature
MTLLibrary only.pub unsafe fn maxTotalThreadsPerObjectThreadgroup(&self) -> NSUInteger
pub unsafe fn setMaxTotalThreadsPerObjectThreadgroup( &self, max_total_threads_per_object_threadgroup: NSUInteger )
pub unsafe fn maxTotalThreadsPerMeshThreadgroup(&self) -> NSUInteger
pub unsafe fn setMaxTotalThreadsPerMeshThreadgroup( &self, max_total_threads_per_mesh_threadgroup: NSUInteger )
pub unsafe fn objectThreadgroupSizeIsMultipleOfThreadExecutionWidth( &self ) -> bool
pub unsafe fn setObjectThreadgroupSizeIsMultipleOfThreadExecutionWidth( &self, object_threadgroup_size_is_multiple_of_thread_execution_width: bool )
pub unsafe fn meshThreadgroupSizeIsMultipleOfThreadExecutionWidth(&self) -> bool
pub unsafe fn setMeshThreadgroupSizeIsMultipleOfThreadExecutionWidth( &self, mesh_threadgroup_size_is_multiple_of_thread_execution_width: bool )
pub unsafe fn payloadMemoryLength(&self) -> NSUInteger
pub unsafe fn setPayloadMemoryLength(&self, payload_memory_length: NSUInteger)
pub unsafe fn maxTotalThreadgroupsPerMeshGrid(&self) -> NSUInteger
pub unsafe fn setMaxTotalThreadgroupsPerMeshGrid( &self, max_total_threadgroups_per_mesh_grid: NSUInteger )
pub unsafe fn objectBuffers(&self) -> Retained<MTLPipelineBufferDescriptorArray>
Available on crate feature
MTLPipeline only.pub unsafe fn meshBuffers(&self) -> Retained<MTLPipelineBufferDescriptorArray>
Available on crate feature
MTLPipeline only.pub unsafe fn fragmentBuffers( &self ) -> Retained<MTLPipelineBufferDescriptorArray>
Available on crate feature
MTLPipeline only.pub unsafe fn rasterSampleCount(&self) -> NSUInteger
pub unsafe fn setRasterSampleCount(&self, raster_sample_count: NSUInteger)
pub unsafe fn isAlphaToCoverageEnabled(&self) -> bool
pub unsafe fn setAlphaToCoverageEnabled(&self, alpha_to_coverage_enabled: bool)
pub unsafe fn isAlphaToOneEnabled(&self) -> bool
pub unsafe fn setAlphaToOneEnabled(&self, alpha_to_one_enabled: bool)
pub unsafe fn isRasterizationEnabled(&self) -> bool
pub unsafe fn setRasterizationEnabled(&self, rasterization_enabled: bool)
pub unsafe fn maxVertexAmplificationCount(&self) -> NSUInteger
pub unsafe fn setMaxVertexAmplificationCount( &self, max_vertex_amplification_count: NSUInteger )
pub unsafe fn colorAttachments( &self ) -> Retained<MTLRenderPipelineColorAttachmentDescriptorArray>
pub unsafe fn depthAttachmentPixelFormat(&self) -> MTLPixelFormat
Available on crate feature
MTLPixelFormat only.pub unsafe fn setDepthAttachmentPixelFormat( &self, depth_attachment_pixel_format: MTLPixelFormat )
Available on crate feature
MTLPixelFormat only.pub unsafe fn stencilAttachmentPixelFormat(&self) -> MTLPixelFormat
Available on crate feature
MTLPixelFormat only.pub unsafe fn setStencilAttachmentPixelFormat( &self, stencil_attachment_pixel_format: MTLPixelFormat )
Available on crate feature
MTLPixelFormat only.pub unsafe fn supportIndirectCommandBuffers(&self) -> bool
pub unsafe fn setSupportIndirectCommandBuffers( &self, support_indirect_command_buffers: bool )
pub unsafe fn objectLinkedFunctions(&self) -> Retained<MTLLinkedFunctions>
Available on crate feature
MTLLinkedFunctions only.pub unsafe fn setObjectLinkedFunctions( &self, object_linked_functions: Option<&MTLLinkedFunctions> )
Available on crate feature
MTLLinkedFunctions only.pub unsafe fn meshLinkedFunctions(&self) -> Retained<MTLLinkedFunctions>
Available on crate feature
MTLLinkedFunctions only.pub unsafe fn setMeshLinkedFunctions( &self, mesh_linked_functions: Option<&MTLLinkedFunctions> )
Available on crate feature
MTLLinkedFunctions only.pub unsafe fn fragmentLinkedFunctions(&self) -> Retained<MTLLinkedFunctions>
Available on crate feature
MTLLinkedFunctions only.pub unsafe fn setFragmentLinkedFunctions( &self, fragment_linked_functions: Option<&MTLLinkedFunctions> )
Available on crate feature
MTLLinkedFunctions only.pub unsafe fn reset(&self)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.