#[repr(C)]pub struct MTLPrimitiveAccelerationStructureDescriptor { /* private fields */ }Available on crate feature
MTLAccelerationStructure only.Implementations
sourceimpl MTLPrimitiveAccelerationStructureDescriptor
impl MTLPrimitiveAccelerationStructureDescriptor
pub unsafe fn geometryDescriptors( &self ) -> Option<Retained<NSArray<MTLAccelerationStructureGeometryDescriptor>>>
pub fn setGeometryDescriptors( &self, geometry_descriptors: Option<&NSArray<MTLAccelerationStructureGeometryDescriptor>> )
pub unsafe fn motionStartBorderMode(&self) -> MTLMotionBorderMode
pub unsafe fn setMotionStartBorderMode( &self, motion_start_border_mode: MTLMotionBorderMode )
pub unsafe fn motionEndBorderMode(&self) -> MTLMotionBorderMode
pub unsafe fn setMotionEndBorderMode( &self, motion_end_border_mode: MTLMotionBorderMode )
pub unsafe fn motionStartTime(&self) -> c_float
pub unsafe fn setMotionStartTime(&self, motion_start_time: c_float)
pub unsafe fn motionEndTime(&self) -> c_float
pub unsafe fn setMotionEndTime(&self, motion_end_time: c_float)
pub unsafe fn motionKeyframeCount(&self) -> NSUInteger
pub unsafe fn setMotionKeyframeCount(&self, motion_keyframe_count: NSUInteger)
pub fn descriptor() -> Retained<Self>
Methods from Deref<Target = MTLAccelerationStructureDescriptor>
pub unsafe fn usage(&self) -> MTLAccelerationStructureUsage
pub unsafe fn setUsage(&self, usage: MTLAccelerationStructureUsage)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.