#[repr(C)]pub struct MTLRenderPassDepthAttachmentDescriptor { /* private fields */ }Available on crate feature
MTLRenderPass only.Implementations
sourceimpl MTLRenderPassDepthAttachmentDescriptor
impl MTLRenderPassDepthAttachmentDescriptor
pub fn clearDepth(&self) -> c_double
pub fn setClearDepth(&self, clear_depth: c_double)
pub fn depthResolveFilter(&self) -> MTLMultisampleDepthResolveFilter
pub fn setDepthResolveFilter( &self, depth_resolve_filter: MTLMultisampleDepthResolveFilter )
Methods from Deref<Target = MTLRenderPassAttachmentDescriptor>
pub fn texture(&self) -> Option<Retained<ProtocolObject<dyn MTLTexture>>>
Available on crate features
MTLResource and MTLTexture only.pub fn setTexture(&self, texture: Option<&ProtocolObject<dyn MTLTexture>>)
Available on crate features
MTLResource and MTLTexture only.pub fn level(&self) -> NSUInteger
pub fn setLevel(&self, level: NSUInteger)
pub fn slice(&self) -> NSUInteger
pub fn setSlice(&self, slice: NSUInteger)
pub fn depthPlane(&self) -> NSUInteger
pub fn setDepthPlane(&self, depth_plane: NSUInteger)
pub fn resolveTexture(&self) -> Option<Retained<ProtocolObject<dyn MTLTexture>>>
Available on crate features
MTLResource and MTLTexture only.pub fn setResolveTexture( &self, resolve_texture: Option<&ProtocolObject<dyn MTLTexture>> )
Available on crate features
MTLResource and MTLTexture only.pub fn resolveLevel(&self) -> NSUInteger
pub fn setResolveLevel(&self, resolve_level: NSUInteger)
pub fn resolveSlice(&self) -> NSUInteger
pub fn setResolveSlice(&self, resolve_slice: NSUInteger)
pub fn resolveDepthPlane(&self) -> NSUInteger
pub fn setResolveDepthPlane(&self, resolve_depth_plane: NSUInteger)
pub fn loadAction(&self) -> MTLLoadAction
pub fn setLoadAction(&self, load_action: MTLLoadAction)
pub fn storeAction(&self) -> MTLStoreAction
pub fn setStoreAction(&self, store_action: MTLStoreAction)
pub fn storeActionOptions(&self) -> MTLStoreActionOptions
pub fn setStoreActionOptions(&self, store_action_options: MTLStoreActionOptions)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.