Struct objc2_metal::MTLRenderPassDescriptor
source · #[repr(C)]pub struct MTLRenderPassDescriptor { /* private fields */ }Available on crate feature
MTLRenderPass only.Implementations
sourceimpl MTLRenderPassDescriptor
impl MTLRenderPassDescriptor
pub fn renderPassDescriptor() -> Retained<MTLRenderPassDescriptor>
pub fn colorAttachments( &self ) -> Retained<MTLRenderPassColorAttachmentDescriptorArray>
pub fn depthAttachment( &self ) -> Retained<MTLRenderPassDepthAttachmentDescriptor>
pub fn setDepthAttachment( &self, depth_attachment: Option<&MTLRenderPassDepthAttachmentDescriptor> )
pub fn stencilAttachment( &self ) -> Retained<MTLRenderPassStencilAttachmentDescriptor>
pub fn setStencilAttachment( &self, stencil_attachment: Option<&MTLRenderPassStencilAttachmentDescriptor> )
pub fn visibilityResultBuffer( &self ) -> Option<Retained<ProtocolObject<dyn MTLBuffer>>>
Available on crate features
MTLBuffer and MTLResource only.pub fn setVisibilityResultBuffer( &self, visibility_result_buffer: Option<&ProtocolObject<dyn MTLBuffer>> )
Available on crate features
MTLBuffer and MTLResource only.pub fn renderTargetArrayLength(&self) -> NSUInteger
pub unsafe fn setRenderTargetArrayLength( &self, render_target_array_length: NSUInteger )
pub fn imageblockSampleLength(&self) -> NSUInteger
pub unsafe fn setImageblockSampleLength( &self, imageblock_sample_length: NSUInteger )
pub fn threadgroupMemoryLength(&self) -> NSUInteger
pub unsafe fn setThreadgroupMemoryLength( &self, threadgroup_memory_length: NSUInteger )
pub fn tileWidth(&self) -> NSUInteger
pub fn setTileWidth(&self, tile_width: NSUInteger)
pub fn tileHeight(&self) -> NSUInteger
pub fn setTileHeight(&self, tile_height: NSUInteger)
pub fn defaultRasterSampleCount(&self) -> NSUInteger
pub fn setDefaultRasterSampleCount( &self, default_raster_sample_count: NSUInteger )
pub fn renderTargetWidth(&self) -> NSUInteger
pub fn setRenderTargetWidth(&self, render_target_width: NSUInteger)
pub fn renderTargetHeight(&self) -> NSUInteger
pub fn setRenderTargetHeight(&self, render_target_height: NSUInteger)
pub unsafe fn setSamplePositions_count( &self, positions: *mut MTLSamplePosition, count: NSUInteger )
Available on crate feature
MTLTypes only.pub unsafe fn getSamplePositions_count( &self, positions: *mut MTLSamplePosition, count: NSUInteger ) -> NSUInteger
Available on crate feature
MTLTypes only.pub fn rasterizationRateMap( &self ) -> Option<Retained<ProtocolObject<dyn MTLRasterizationRateMap>>>
Available on crate feature
MTLRasterizationRate only.pub fn setRasterizationRateMap( &self, rasterization_rate_map: Option<&ProtocolObject<dyn MTLRasterizationRateMap>> )
Available on crate feature
MTLRasterizationRate only.pub fn sampleBufferAttachments( &self ) -> Retained<MTLRenderPassSampleBufferAttachmentDescriptorArray>
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.