Struct objc2_metal::MTLRenderPipelineDescriptor

source ·
#[repr(C)]
pub struct MTLRenderPipelineDescriptor { /* private fields */ }
Available on crate feature MTLRenderPipeline only.

Implementations

source

impl MTLRenderPipelineDescriptor

source

pub fn label(&self) -> Option<Retained<NSString>>

source

pub fn setLabel(&self, label: Option<&NSString>)

source

pub fn vertexFunction( &self ) -> Option<Retained<ProtocolObject<dyn MTLFunction>>>

Available on crate feature MTLLibrary only.
source

pub fn setVertexFunction( &self, vertex_function: Option<&ProtocolObject<dyn MTLFunction>> )

Available on crate feature MTLLibrary only.
source

pub fn fragmentFunction( &self ) -> Option<Retained<ProtocolObject<dyn MTLFunction>>>

Available on crate feature MTLLibrary only.
source

pub fn setFragmentFunction( &self, fragment_function: Option<&ProtocolObject<dyn MTLFunction>> )

Available on crate feature MTLLibrary only.
source

pub fn vertexDescriptor(&self) -> Option<Retained<MTLVertexDescriptor>>

Available on crate feature MTLVertexDescriptor only.
source

pub fn setVertexDescriptor( &self, vertex_descriptor: Option<&MTLVertexDescriptor> )

Available on crate feature MTLVertexDescriptor only.
source

pub fn sampleCount(&self) -> NSUInteger

👎Deprecated
source

pub fn setSampleCount(&self, sample_count: NSUInteger)

👎Deprecated
source

pub fn rasterSampleCount(&self) -> NSUInteger

source

pub fn setRasterSampleCount(&self, raster_sample_count: NSUInteger)

source

pub fn isAlphaToCoverageEnabled(&self) -> bool

source

pub fn setAlphaToCoverageEnabled(&self, alpha_to_coverage_enabled: bool)

source

pub fn isAlphaToOneEnabled(&self) -> bool

source

pub fn setAlphaToOneEnabled(&self, alpha_to_one_enabled: bool)

source

pub fn isRasterizationEnabled(&self) -> bool

source

pub fn setRasterizationEnabled(&self, rasterization_enabled: bool)

source

pub fn maxVertexAmplificationCount(&self) -> NSUInteger

source

pub unsafe fn setMaxVertexAmplificationCount( &self, max_vertex_amplification_count: NSUInteger )

source

pub fn colorAttachments( &self ) -> Retained<MTLRenderPipelineColorAttachmentDescriptorArray>

source

pub fn depthAttachmentPixelFormat(&self) -> MTLPixelFormat

Available on crate feature MTLPixelFormat only.
source

pub fn setDepthAttachmentPixelFormat( &self, depth_attachment_pixel_format: MTLPixelFormat )

Available on crate feature MTLPixelFormat only.
source

pub fn stencilAttachmentPixelFormat(&self) -> MTLPixelFormat

Available on crate feature MTLPixelFormat only.
source

pub fn setStencilAttachmentPixelFormat( &self, stencil_attachment_pixel_format: MTLPixelFormat )

Available on crate feature MTLPixelFormat only.
source

pub fn inputPrimitiveTopology(&self) -> MTLPrimitiveTopologyClass

source

pub unsafe fn setInputPrimitiveTopology( &self, input_primitive_topology: MTLPrimitiveTopologyClass )

source

pub fn tessellationPartitionMode(&self) -> MTLTessellationPartitionMode

source

pub unsafe fn setTessellationPartitionMode( &self, tessellation_partition_mode: MTLTessellationPartitionMode )

source

pub fn maxTessellationFactor(&self) -> NSUInteger

source

pub unsafe fn setMaxTessellationFactor( &self, max_tessellation_factor: NSUInteger )

source

pub fn isTessellationFactorScaleEnabled(&self) -> bool

source

pub fn setTessellationFactorScaleEnabled( &self, tessellation_factor_scale_enabled: bool )

source

pub fn tessellationFactorFormat(&self) -> MTLTessellationFactorFormat

source

pub fn setTessellationFactorFormat( &self, tessellation_factor_format: MTLTessellationFactorFormat )

source

pub fn tessellationControlPointIndexType( &self ) -> MTLTessellationControlPointIndexType

source

pub unsafe fn setTessellationControlPointIndexType( &self, tessellation_control_point_index_type: MTLTessellationControlPointIndexType )

source

pub fn tessellationFactorStepFunction( &self ) -> MTLTessellationFactorStepFunction

source

pub fn setTessellationFactorStepFunction( &self, tessellation_factor_step_function: MTLTessellationFactorStepFunction )

source

pub fn tessellationOutputWindingOrder(&self) -> MTLWinding

Available on crate feature MTLRenderCommandEncoder only.
source

pub fn setTessellationOutputWindingOrder( &self, tessellation_output_winding_order: MTLWinding )

Available on crate feature MTLRenderCommandEncoder only.
source

pub fn vertexBuffers(&self) -> Retained<MTLPipelineBufferDescriptorArray>

Available on crate feature MTLPipeline only.
source

pub fn fragmentBuffers(&self) -> Retained<MTLPipelineBufferDescriptorArray>

Available on crate feature MTLPipeline only.
source

pub fn supportIndirectCommandBuffers(&self) -> bool

source

pub fn setSupportIndirectCommandBuffers( &self, support_indirect_command_buffers: bool )

source

pub fn binaryArchives( &self ) -> Option<Retained<NSArray<ProtocolObject<dyn MTLBinaryArchive>>>>

Available on crate feature MTLBinaryArchive only.
source

pub fn setBinaryArchives( &self, binary_archives: Option<&NSArray<ProtocolObject<dyn MTLBinaryArchive>>> )

Available on crate feature MTLBinaryArchive only.
source

pub fn vertexPreloadedLibraries( &self ) -> Retained<NSArray<ProtocolObject<dyn MTLDynamicLibrary>>>

Available on crate feature MTLDynamicLibrary only.
source

pub fn setVertexPreloadedLibraries( &self, vertex_preloaded_libraries: &NSArray<ProtocolObject<dyn MTLDynamicLibrary>> )

Available on crate feature MTLDynamicLibrary only.
source

pub fn fragmentPreloadedLibraries( &self ) -> Retained<NSArray<ProtocolObject<dyn MTLDynamicLibrary>>>

Available on crate feature MTLDynamicLibrary only.
source

pub fn setFragmentPreloadedLibraries( &self, fragment_preloaded_libraries: &NSArray<ProtocolObject<dyn MTLDynamicLibrary>> )

Available on crate feature MTLDynamicLibrary only.
source

pub fn vertexLinkedFunctions(&self) -> Retained<MTLLinkedFunctions>

Available on crate feature MTLLinkedFunctions only.
source

pub fn setVertexLinkedFunctions( &self, vertex_linked_functions: Option<&MTLLinkedFunctions> )

Available on crate feature MTLLinkedFunctions only.
source

pub fn fragmentLinkedFunctions(&self) -> Retained<MTLLinkedFunctions>

Available on crate feature MTLLinkedFunctions only.
source

pub fn setFragmentLinkedFunctions( &self, fragment_linked_functions: Option<&MTLLinkedFunctions> )

Available on crate feature MTLLinkedFunctions only.
source

pub fn supportAddingVertexBinaryFunctions(&self) -> bool

source

pub fn setSupportAddingVertexBinaryFunctions( &self, support_adding_vertex_binary_functions: bool )

source

pub fn supportAddingFragmentBinaryFunctions(&self) -> bool

source

pub fn setSupportAddingFragmentBinaryFunctions( &self, support_adding_fragment_binary_functions: bool )

source

pub fn maxVertexCallStackDepth(&self) -> NSUInteger

source

pub fn setMaxVertexCallStackDepth( &self, max_vertex_call_stack_depth: NSUInteger )

source

pub fn maxFragmentCallStackDepth(&self) -> NSUInteger

source

pub fn setMaxFragmentCallStackDepth( &self, max_fragment_call_stack_depth: NSUInteger )

source

pub fn reset(&self)

source

impl MTLRenderPipelineDescriptor

Methods declared on superclass NSObject

source

pub fn init(this: Allocated<Self>) -> Retained<Self>

source

pub fn new() -> Retained<Self>

Methods from Deref<Target = NSObject>

source

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.