Struct objc2_metal::MTLSamplerDescriptor
source · #[repr(C)]pub struct MTLSamplerDescriptor { /* private fields */ }Available on crate feature
MTLSampler only.Implementations
sourceimpl MTLSamplerDescriptor
impl MTLSamplerDescriptor
pub fn minFilter(&self) -> MTLSamplerMinMagFilter
pub fn setMinFilter(&self, min_filter: MTLSamplerMinMagFilter)
pub fn magFilter(&self) -> MTLSamplerMinMagFilter
pub fn setMagFilter(&self, mag_filter: MTLSamplerMinMagFilter)
pub fn mipFilter(&self) -> MTLSamplerMipFilter
pub fn setMipFilter(&self, mip_filter: MTLSamplerMipFilter)
pub fn maxAnisotropy(&self) -> NSUInteger
pub fn setMaxAnisotropy(&self, max_anisotropy: NSUInteger)
pub fn sAddressMode(&self) -> MTLSamplerAddressMode
pub fn setSAddressMode(&self, s_address_mode: MTLSamplerAddressMode)
pub fn tAddressMode(&self) -> MTLSamplerAddressMode
pub fn setTAddressMode(&self, t_address_mode: MTLSamplerAddressMode)
pub fn rAddressMode(&self) -> MTLSamplerAddressMode
pub fn setRAddressMode(&self, r_address_mode: MTLSamplerAddressMode)
pub fn borderColor(&self) -> MTLSamplerBorderColor
pub fn setBorderColor(&self, border_color: MTLSamplerBorderColor)
pub fn normalizedCoordinates(&self) -> bool
pub fn setNormalizedCoordinates(&self, normalized_coordinates: bool)
pub fn lodMinClamp(&self) -> c_float
pub fn setLodMinClamp(&self, lod_min_clamp: c_float)
pub fn lodMaxClamp(&self) -> c_float
pub fn setLodMaxClamp(&self, lod_max_clamp: c_float)
pub fn lodAverage(&self) -> bool
pub fn setLodAverage(&self, lod_average: bool)
pub fn compareFunction(&self) -> MTLCompareFunction
Available on crate feature
MTLDepthStencil only.pub fn setCompareFunction(&self, compare_function: MTLCompareFunction)
Available on crate feature
MTLDepthStencil only.pub fn supportArgumentBuffers(&self) -> bool
pub fn setSupportArgumentBuffers(&self, support_argument_buffers: bool)
pub fn label(&self) -> Option<Retained<NSString>>
pub fn setLabel(&self, label: Option<&NSString>)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.