Struct objc2_metal::MTLTextureDescriptor

source ·
#[repr(C)]
pub struct MTLTextureDescriptor { /* private fields */ }
Available on crate feature MTLTexture only.

Implementations

source

impl MTLTextureDescriptor

source

pub unsafe fn texture2DDescriptorWithPixelFormat_width_height_mipmapped( pixel_format: MTLPixelFormat, width: NSUInteger, height: NSUInteger, mipmapped: bool ) -> Retained<MTLTextureDescriptor>

Available on crate feature MTLPixelFormat only.
source

pub unsafe fn textureCubeDescriptorWithPixelFormat_size_mipmapped( pixel_format: MTLPixelFormat, size: NSUInteger, mipmapped: bool ) -> Retained<MTLTextureDescriptor>

Available on crate feature MTLPixelFormat only.
source

pub unsafe fn textureBufferDescriptorWithPixelFormat_width_resourceOptions_usage( pixel_format: MTLPixelFormat, width: NSUInteger, resource_options: MTLResourceOptions, usage: MTLTextureUsage ) -> Retained<MTLTextureDescriptor>

Available on crate features MTLPixelFormat and MTLResource only.
source

pub fn textureType(&self) -> MTLTextureType

source

pub fn setTextureType(&self, texture_type: MTLTextureType)

source

pub fn pixelFormat(&self) -> MTLPixelFormat

Available on crate feature MTLPixelFormat only.
source

pub fn setPixelFormat(&self, pixel_format: MTLPixelFormat)

Available on crate feature MTLPixelFormat only.
source

pub fn width(&self) -> NSUInteger

source

pub unsafe fn setWidth(&self, width: NSUInteger)

source

pub fn height(&self) -> NSUInteger

source

pub unsafe fn setHeight(&self, height: NSUInteger)

source

pub fn depth(&self) -> NSUInteger

source

pub unsafe fn setDepth(&self, depth: NSUInteger)

source

pub fn mipmapLevelCount(&self) -> NSUInteger

source

pub unsafe fn setMipmapLevelCount(&self, mipmap_level_count: NSUInteger)

source

pub fn sampleCount(&self) -> NSUInteger

source

pub unsafe fn setSampleCount(&self, sample_count: NSUInteger)

source

pub fn arrayLength(&self) -> NSUInteger

source

pub unsafe fn setArrayLength(&self, array_length: NSUInteger)

source

pub fn resourceOptions(&self) -> MTLResourceOptions

Available on crate feature MTLResource only.
source

pub fn setResourceOptions(&self, resource_options: MTLResourceOptions)

Available on crate feature MTLResource only.
source

pub fn cpuCacheMode(&self) -> MTLCPUCacheMode

Available on crate feature MTLResource only.
source

pub fn setCpuCacheMode(&self, cpu_cache_mode: MTLCPUCacheMode)

Available on crate feature MTLResource only.
source

pub fn storageMode(&self) -> MTLStorageMode

Available on crate feature MTLResource only.
source

pub fn setStorageMode(&self, storage_mode: MTLStorageMode)

Available on crate feature MTLResource only.
source

pub fn hazardTrackingMode(&self) -> MTLHazardTrackingMode

Available on crate feature MTLResource only.
source

pub fn setHazardTrackingMode(&self, hazard_tracking_mode: MTLHazardTrackingMode)

Available on crate feature MTLResource only.
source

pub fn usage(&self) -> MTLTextureUsage

source

pub fn setUsage(&self, usage: MTLTextureUsage)

source

pub fn allowGPUOptimizedContents(&self) -> bool

source

pub fn setAllowGPUOptimizedContents(&self, allow_gpu_optimized_contents: bool)

source

pub unsafe fn compressionType(&self) -> MTLTextureCompressionType

source

pub unsafe fn setCompressionType( &self, compression_type: MTLTextureCompressionType )

source

pub fn swizzle(&self) -> MTLTextureSwizzleChannels

source

pub fn setSwizzle(&self, swizzle: MTLTextureSwizzleChannels)

source

impl MTLTextureDescriptor

Methods declared on superclass NSObject

source

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

source

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = NSObject>

source

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.