MTL4CompilerTask

Trait MTL4CompilerTask 

pub unsafe trait MTL4CompilerTask: NSObjectProtocol {
    // Provided methods
    fn compiler(&self) -> Retained<ProtocolObject<dyn MTL4Compiler>>
       where Self: Sized + Message { ... }
    fn status(&self) -> MTL4CompilerTaskStatus
       where Self: Sized + Message { ... }
    fn waitUntilCompleted(&self)
       where Self: Sized + Message { ... }
}
Available on crate feature MTL4CompilerTask only.
A reference to an asynchronous compilation task that you initiate from a compiler instance.

See also Apple’s documentation

Provided Methods

fn compiler(&self) -> Retained<ProtocolObject<dyn MTL4Compiler>>
where Self: Sized + Message,

Available on crate feature MTL4Compiler only.

Returns the compiler instance that this asynchronous compiler task belongs to.

fn status(&self) -> MTL4CompilerTaskStatus
where Self: Sized + Message,

Returns the compiler task status.

The default is MTL4CompilerStatusNone.

fn waitUntilCompleted(&self)
where Self: Sized + Message,

Waits synchronously for this compile task to complete by blocking the calling thread.