MTLParallelRenderCommandEncoder

Trait MTLParallelRenderCommandEncoder 

pub unsafe trait MTLParallelRenderCommandEncoder: MTLCommandEncoder {
    // Provided methods
    fn renderCommandEncoder(
        &self,
    ) -> Option<Retained<ProtocolObject<dyn MTLRenderCommandEncoder>>>
       where Self: Sized + Message { ... }
    unsafe fn setColorStoreAction_atIndex(
        &self,
        store_action: MTLStoreAction,
        color_attachment_index: NSUInteger,
    )
       where Self: Sized + Message { ... }
    fn setDepthStoreAction(&self, store_action: MTLStoreAction)
       where Self: Sized + Message { ... }
    fn setStencilStoreAction(&self, store_action: MTLStoreAction)
       where Self: Sized + Message { ... }
    unsafe fn setColorStoreActionOptions_atIndex(
        &self,
        store_action_options: MTLStoreActionOptions,
        color_attachment_index: NSUInteger,
    )
       where Self: Sized + Message { ... }
    fn setDepthStoreActionOptions(
        &self,
        store_action_options: MTLStoreActionOptions,
    )
       where Self: Sized + Message { ... }
    fn setStencilStoreActionOptions(
        &self,
        store_action_options: MTLStoreActionOptions,
    )
       where Self: Sized + Message { ... }
}
Available on crate features MTLCommandEncoder and MTLParallelRenderCommandEncoder only.
The MTLParallelRenderCommandEncoder protocol is designed to allow a single render to texture operation to be efficiently (and safely) broken up across multiple threads.

See also Apple’s documentation

Provided Methods

fn renderCommandEncoder( &self, ) -> Option<Retained<ProtocolObject<dyn MTLRenderCommandEncoder>>>
where Self: Sized + Message,

Available on crate feature MTLRenderCommandEncoder only.

Return a new autoreleased object that conforms to <MTLRenderCommandEncoder

that may be used to encode on a different thread.

unsafe fn setColorStoreAction_atIndex( &self, store_action: MTLStoreAction, color_attachment_index: NSUInteger, )
where Self: Sized + Message,

Available on crate feature MTLRenderPass only.

If the the store action for a given color attachment was set to MTLStoreActionUnknown when the render command encoder was created, setColorStoreAction:atIndex: must be used to finalize the store action before endEncoding is called.

Parameter storeAction: The desired store action for the given color attachment. This may be set to any value other than MTLStoreActionUnknown.

Parameter colorAttachmentIndex: The index of the color attachment

Safety

colorAttachmentIndex might not be bounds-checked.

fn setDepthStoreAction(&self, store_action: MTLStoreAction)
where Self: Sized + Message,

Available on crate feature MTLRenderPass only.

If the the store action for the depth attachment was set to MTLStoreActionUnknown when the render command encoder was created, setDepthStoreAction: must be used to finalize the store action before endEncoding is called.

fn setStencilStoreAction(&self, store_action: MTLStoreAction)
where Self: Sized + Message,

Available on crate feature MTLRenderPass only.

If the the store action for the stencil attachment was set to MTLStoreActionUnknown when the render command encoder was created, setStencilStoreAction: must be used to finalize the store action before endEncoding is called.

unsafe fn setColorStoreActionOptions_atIndex( &self, store_action_options: MTLStoreActionOptions, color_attachment_index: NSUInteger, )
where Self: Sized + Message,

Available on crate feature MTLRenderPass only.

If the the store action for a given color attachment was set to MTLStoreActionUnknown when the render command encoder was created, setColorStoreActionOptions:atIndex: may be used to finalize the store action options before endEncoding is called.

Parameter storeActionOptions: The desired store action options for the given color attachment.

Parameter colorAttachmentIndex: The index of the color attachment

Safety

colorAttachmentIndex might not be bounds-checked.

fn setDepthStoreActionOptions( &self, store_action_options: MTLStoreActionOptions, )
where Self: Sized + Message,

Available on crate feature MTLRenderPass only.

If the the store action for the depth attachment was set to MTLStoreActionUnknown when the render command encoder was created, setDepthStoreActionOptions: may be used to finalize the store action options before endEncoding is called.

fn setStencilStoreActionOptions( &self, store_action_options: MTLStoreActionOptions, )
where Self: Sized + Message,

Available on crate feature MTLRenderPass only.

If the the store action for the stencil attachment was set to MTLStoreActionUnknown when the render command encoder was created, setStencilStoreActionOptions: may be used to finalize the store action options before endEncoding is called.