MTLVisibleFunctionTable

Trait MTLVisibleFunctionTable 

pub unsafe trait MTLVisibleFunctionTable: MTLResource {
    // Provided methods
    fn gpuResourceID(&self) -> MTLResourceID
       where Self: Sized + Message { ... }
    unsafe fn setFunction_atIndex(
        &self,
        function: Option<&ProtocolObject<dyn MTLFunctionHandle>>,
        index: NSUInteger,
    )
       where Self: Sized + Message { ... }
    unsafe fn setFunctions_withRange(
        &self,
        functions: NonNull<*const ProtocolObject<dyn MTLFunctionHandle>>,
        range: NSRange,
    )
       where Self: Sized + Message { ... }
}
Available on crate features MTLAllocation and MTLResource and MTLVisibleFunctionTable only.
Provided Methods

fn gpuResourceID(&self) -> MTLResourceID
where Self: Sized + Message,

Available on crate feature MTLTypes only.

Handle of the GPU resource suitable for storing in an Argument Buffer

unsafe fn setFunction_atIndex( &self, function: Option<&ProtocolObject<dyn MTLFunctionHandle>>, index: NSUInteger, )
where Self: Sized + Message,

Available on crate feature MTLFunctionHandle only.
Safety
  • function must be safe to call.
  • function must have the correct argument and return types.
  • index might not be bounds-checked.
unsafe fn setFunctions_withRange( &self, functions: NonNull<*const ProtocolObject<dyn MTLFunctionHandle>>, range: NSRange, )
where Self: Sized + Message,

Available on crate feature MTLFunctionHandle only.
Safety
  • functions must be a valid pointer.
  • range might not be bounds-checked.