pub type MTL4NewBinaryFunctionCompletionHandler = *mut DynBlock<dyn Fn(*mut ProtocolObject<dyn MTL4BinaryFunction>, *mut NSError)>;Available on crate features
block2 and MTL4BinaryFunction and MTL4Compiler only.Expand description
Provides a signature for a callback block that Metal calls when the compiler finishes a build task for a binary function.
See also Appleās documentation