Struct objc2_metal::MTLRenderPipelineDescriptor
source · #[repr(C)]pub struct MTLRenderPipelineDescriptor { /* private fields */ }Available on crate feature
MTLRenderPipeline only.Implementations
sourceimpl MTLRenderPipelineDescriptor
impl MTLRenderPipelineDescriptor
pub fn label(&self) -> Option<Retained<NSString>>
pub fn setLabel(&self, label: Option<&NSString>)
pub fn vertexFunction( &self ) -> Option<Retained<ProtocolObject<dyn MTLFunction>>>
Available on crate feature
MTLLibrary only.pub fn setVertexFunction( &self, vertex_function: Option<&ProtocolObject<dyn MTLFunction>> )
Available on crate feature
MTLLibrary only.pub fn fragmentFunction( &self ) -> Option<Retained<ProtocolObject<dyn MTLFunction>>>
Available on crate feature
MTLLibrary only.pub fn setFragmentFunction( &self, fragment_function: Option<&ProtocolObject<dyn MTLFunction>> )
Available on crate feature
MTLLibrary only.pub fn vertexDescriptor(&self) -> Option<Retained<MTLVertexDescriptor>>
Available on crate feature
MTLVertexDescriptor only.pub fn setVertexDescriptor( &self, vertex_descriptor: Option<&MTLVertexDescriptor> )
Available on crate feature
MTLVertexDescriptor only.pub fn sampleCount(&self) -> NSUInteger
👎Deprecated
pub fn setSampleCount(&self, sample_count: NSUInteger)
👎Deprecated
pub fn rasterSampleCount(&self) -> NSUInteger
pub fn setRasterSampleCount(&self, raster_sample_count: NSUInteger)
pub fn isAlphaToCoverageEnabled(&self) -> bool
pub fn setAlphaToCoverageEnabled(&self, alpha_to_coverage_enabled: bool)
pub fn isAlphaToOneEnabled(&self) -> bool
pub fn setAlphaToOneEnabled(&self, alpha_to_one_enabled: bool)
pub fn isRasterizationEnabled(&self) -> bool
pub fn setRasterizationEnabled(&self, rasterization_enabled: bool)
pub fn maxVertexAmplificationCount(&self) -> NSUInteger
pub unsafe fn setMaxVertexAmplificationCount( &self, max_vertex_amplification_count: NSUInteger )
pub fn colorAttachments( &self ) -> Retained<MTLRenderPipelineColorAttachmentDescriptorArray>
pub fn depthAttachmentPixelFormat(&self) -> MTLPixelFormat
Available on crate feature
MTLPixelFormat only.pub fn setDepthAttachmentPixelFormat( &self, depth_attachment_pixel_format: MTLPixelFormat )
Available on crate feature
MTLPixelFormat only.pub fn stencilAttachmentPixelFormat(&self) -> MTLPixelFormat
Available on crate feature
MTLPixelFormat only.pub fn setStencilAttachmentPixelFormat( &self, stencil_attachment_pixel_format: MTLPixelFormat )
Available on crate feature
MTLPixelFormat only.pub fn inputPrimitiveTopology(&self) -> MTLPrimitiveTopologyClass
pub unsafe fn setInputPrimitiveTopology( &self, input_primitive_topology: MTLPrimitiveTopologyClass )
pub fn tessellationPartitionMode(&self) -> MTLTessellationPartitionMode
pub unsafe fn setTessellationPartitionMode( &self, tessellation_partition_mode: MTLTessellationPartitionMode )
pub fn maxTessellationFactor(&self) -> NSUInteger
pub unsafe fn setMaxTessellationFactor( &self, max_tessellation_factor: NSUInteger )
pub fn isTessellationFactorScaleEnabled(&self) -> bool
pub fn setTessellationFactorScaleEnabled( &self, tessellation_factor_scale_enabled: bool )
pub fn tessellationFactorFormat(&self) -> MTLTessellationFactorFormat
pub fn setTessellationFactorFormat( &self, tessellation_factor_format: MTLTessellationFactorFormat )
pub fn tessellationControlPointIndexType( &self ) -> MTLTessellationControlPointIndexType
pub unsafe fn setTessellationControlPointIndexType( &self, tessellation_control_point_index_type: MTLTessellationControlPointIndexType )
pub fn tessellationFactorStepFunction( &self ) -> MTLTessellationFactorStepFunction
pub fn setTessellationFactorStepFunction( &self, tessellation_factor_step_function: MTLTessellationFactorStepFunction )
pub fn tessellationOutputWindingOrder(&self) -> MTLWinding
Available on crate feature
MTLRenderCommandEncoder only.pub fn setTessellationOutputWindingOrder( &self, tessellation_output_winding_order: MTLWinding )
Available on crate feature
MTLRenderCommandEncoder only.pub fn vertexBuffers(&self) -> Retained<MTLPipelineBufferDescriptorArray>
Available on crate feature
MTLPipeline only.pub fn fragmentBuffers(&self) -> Retained<MTLPipelineBufferDescriptorArray>
Available on crate feature
MTLPipeline only.pub fn supportIndirectCommandBuffers(&self) -> bool
pub fn setSupportIndirectCommandBuffers( &self, support_indirect_command_buffers: bool )
pub fn binaryArchives( &self ) -> Option<Retained<NSArray<ProtocolObject<dyn MTLBinaryArchive>>>>
Available on crate feature
MTLBinaryArchive only.pub fn setBinaryArchives( &self, binary_archives: Option<&NSArray<ProtocolObject<dyn MTLBinaryArchive>>> )
Available on crate feature
MTLBinaryArchive only.pub fn vertexPreloadedLibraries( &self ) -> Retained<NSArray<ProtocolObject<dyn MTLDynamicLibrary>>>
Available on crate feature
MTLDynamicLibrary only.pub fn setVertexPreloadedLibraries( &self, vertex_preloaded_libraries: &NSArray<ProtocolObject<dyn MTLDynamicLibrary>> )
Available on crate feature
MTLDynamicLibrary only.pub fn fragmentPreloadedLibraries( &self ) -> Retained<NSArray<ProtocolObject<dyn MTLDynamicLibrary>>>
Available on crate feature
MTLDynamicLibrary only.pub fn setFragmentPreloadedLibraries( &self, fragment_preloaded_libraries: &NSArray<ProtocolObject<dyn MTLDynamicLibrary>> )
Available on crate feature
MTLDynamicLibrary only.pub fn vertexLinkedFunctions(&self) -> Retained<MTLLinkedFunctions>
Available on crate feature
MTLLinkedFunctions only.pub fn setVertexLinkedFunctions( &self, vertex_linked_functions: Option<&MTLLinkedFunctions> )
Available on crate feature
MTLLinkedFunctions only.pub fn fragmentLinkedFunctions(&self) -> Retained<MTLLinkedFunctions>
Available on crate feature
MTLLinkedFunctions only.pub fn setFragmentLinkedFunctions( &self, fragment_linked_functions: Option<&MTLLinkedFunctions> )
Available on crate feature
MTLLinkedFunctions only.pub fn supportAddingVertexBinaryFunctions(&self) -> bool
pub fn setSupportAddingVertexBinaryFunctions( &self, support_adding_vertex_binary_functions: bool )
pub fn supportAddingFragmentBinaryFunctions(&self) -> bool
pub fn setSupportAddingFragmentBinaryFunctions( &self, support_adding_fragment_binary_functions: bool )
pub fn maxVertexCallStackDepth(&self) -> NSUInteger
pub fn setMaxVertexCallStackDepth( &self, max_vertex_call_stack_depth: NSUInteger )
pub fn maxFragmentCallStackDepth(&self) -> NSUInteger
pub fn setMaxFragmentCallStackDepth( &self, max_fragment_call_stack_depth: NSUInteger )
pub fn reset(&self)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.