Struct objc2_metal::MTLTextureDescriptor
source · #[repr(C)]pub struct MTLTextureDescriptor { /* private fields */ }Available on crate feature
MTLTexture only.Implementations
sourceimpl MTLTextureDescriptor
impl MTLTextureDescriptor
pub unsafe fn texture2DDescriptorWithPixelFormat_width_height_mipmapped( pixel_format: MTLPixelFormat, width: NSUInteger, height: NSUInteger, mipmapped: bool ) -> Retained<MTLTextureDescriptor>
Available on crate feature
MTLPixelFormat only.pub unsafe fn textureCubeDescriptorWithPixelFormat_size_mipmapped( pixel_format: MTLPixelFormat, size: NSUInteger, mipmapped: bool ) -> Retained<MTLTextureDescriptor>
Available on crate feature
MTLPixelFormat only.pub unsafe fn textureBufferDescriptorWithPixelFormat_width_resourceOptions_usage( pixel_format: MTLPixelFormat, width: NSUInteger, resource_options: MTLResourceOptions, usage: MTLTextureUsage ) -> Retained<MTLTextureDescriptor>
Available on crate features
MTLPixelFormat and MTLResource only.pub fn textureType(&self) -> MTLTextureType
pub fn setTextureType(&self, texture_type: MTLTextureType)
pub fn pixelFormat(&self) -> MTLPixelFormat
Available on crate feature
MTLPixelFormat only.pub fn setPixelFormat(&self, pixel_format: MTLPixelFormat)
Available on crate feature
MTLPixelFormat only.pub fn width(&self) -> NSUInteger
pub unsafe fn setWidth(&self, width: NSUInteger)
pub fn height(&self) -> NSUInteger
pub unsafe fn setHeight(&self, height: NSUInteger)
pub fn depth(&self) -> NSUInteger
pub unsafe fn setDepth(&self, depth: NSUInteger)
pub fn mipmapLevelCount(&self) -> NSUInteger
pub unsafe fn setMipmapLevelCount(&self, mipmap_level_count: NSUInteger)
pub fn sampleCount(&self) -> NSUInteger
pub unsafe fn setSampleCount(&self, sample_count: NSUInteger)
pub fn arrayLength(&self) -> NSUInteger
pub unsafe fn setArrayLength(&self, array_length: NSUInteger)
pub fn resourceOptions(&self) -> MTLResourceOptions
Available on crate feature
MTLResource only.pub fn setResourceOptions(&self, resource_options: MTLResourceOptions)
Available on crate feature
MTLResource only.pub fn cpuCacheMode(&self) -> MTLCPUCacheMode
Available on crate feature
MTLResource only.pub fn setCpuCacheMode(&self, cpu_cache_mode: MTLCPUCacheMode)
Available on crate feature
MTLResource only.pub fn storageMode(&self) -> MTLStorageMode
Available on crate feature
MTLResource only.pub fn setStorageMode(&self, storage_mode: MTLStorageMode)
Available on crate feature
MTLResource only.pub fn hazardTrackingMode(&self) -> MTLHazardTrackingMode
Available on crate feature
MTLResource only.pub fn setHazardTrackingMode(&self, hazard_tracking_mode: MTLHazardTrackingMode)
Available on crate feature
MTLResource only.pub fn usage(&self) -> MTLTextureUsage
pub fn setUsage(&self, usage: MTLTextureUsage)
pub fn allowGPUOptimizedContents(&self) -> bool
pub fn setAllowGPUOptimizedContents(&self, allow_gpu_optimized_contents: bool)
pub unsafe fn compressionType(&self) -> MTLTextureCompressionType
pub unsafe fn setCompressionType( &self, compression_type: MTLTextureCompressionType )
pub fn swizzle(&self) -> MTLTextureSwizzleChannels
pub fn setSwizzle(&self, swizzle: MTLTextureSwizzleChannels)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.