pub unsafe trait MTL4CompilerTask: NSObjectProtocol {
// Provided methods
fn compiler(&self) -> Retained<ProtocolObject<dyn MTL4Compiler>>
where Self: Sized + Message { ... }
fn status(&self) -> MTL4CompilerTaskStatus
where Self: Sized + Message { ... }
fn waitUntilCompleted(&self)
where Self: Sized + Message { ... }
}Available on crate feature
MTL4CompilerTask only.Expand description
A reference to an asynchronous compilation task that you initiate from a compiler instance.
See also Apple’s documentation
Provided Methods
Sourcefn compiler(&self) -> Retained<ProtocolObject<dyn MTL4Compiler>>
Available on crate feature MTL4Compiler only.
fn compiler(&self) -> Retained<ProtocolObject<dyn MTL4Compiler>>
MTL4Compiler only.Returns the compiler instance that this asynchronous compiler task belongs to.
Sourcefn status(&self) -> MTL4CompilerTaskStatus
fn status(&self) -> MTL4CompilerTaskStatus
Returns the compiler task status.
The default is MTL4CompilerStatusNone.
Sourcefn waitUntilCompleted(&self)
fn waitUntilCompleted(&self)
Waits synchronously for this compile task to complete by blocking the calling thread.