pub unsafe trait MTLFunctionHandle:
NSObjectProtocol
+ Send
+ Sync {
// Provided methods
fn functionType(&self) -> MTLFunctionType
where Self: Sized + Message { ... }
fn name(&self) -> Retained<NSString>
where Self: Sized + Message { ... }
fn device(&self) -> Retained<ProtocolObject<dyn MTLDevice>>
where Self: Sized + Message { ... }
fn gpuResourceID(&self) -> MTLResourceID
where Self: Sized + Message { ... }
}Available on crate feature
MTLFunctionHandle only.Expand description
Provided Methods
fn functionType(&self) -> MTLFunctionType
Available on crate feature
MTLLibrary only.fn name(&self) -> Retained<NSString>
fn device(&self) -> Retained<ProtocolObject<dyn MTLDevice>>
Available on crate feature
MTLDevice only.Sourcefn gpuResourceID(&self) -> MTLResourceID
Available on crate feature MTLTypes only.
fn gpuResourceID(&self) -> MTLResourceID
MTLTypes only.Handle of the GPU resource suitable for storing in an Intersection Function Buffer.
The handle must have been created from an intersection function annotated with the intersection_function_buffer tag.