pub unsafe trait MTLResourceViewPool: NSObjectProtocol {
// Provided methods
fn baseResourceID(&self) -> MTLResourceID
where Self: Sized + Message { ... }
fn resourceViewCount(&self) -> NSUInteger
where Self: Sized + Message { ... }
fn device(&self) -> Retained<ProtocolObject<dyn MTLDevice>>
where Self: Sized + Message { ... }
fn label(&self) -> Option<Retained<NSString>>
where Self: Sized + Message { ... }
unsafe fn copyResourceViewsFromPool_sourceRange_destinationIndex(
&self,
source_pool: &ProtocolObject<dyn MTLResourceViewPool>,
source_range: NSRange,
destination_index: NSUInteger,
) -> MTLResourceID
where Self: Sized + Message { ... }
}MTLResourceViewPool only.Expand description
Contains views over resources of a specific type, and allows you to manage those views.
See also Apple’s documentation
Provided Methods
Sourcefn baseResourceID(&self) -> MTLResourceID
Available on crate feature MTLTypes only.
fn baseResourceID(&self) -> MTLResourceID
MTLTypes only.Obtains the resource ID corresponding to the resource view at index 0 in this resource view pool.
Sourcefn resourceViewCount(&self) -> NSUInteger
fn resourceViewCount(&self) -> NSUInteger
Queries the number of resource views that this pool contains.
Sourcefn device(&self) -> Retained<ProtocolObject<dyn MTLDevice>>
Available on crate feature MTLDevice only.
fn device(&self) -> Retained<ProtocolObject<dyn MTLDevice>>
MTLDevice only.Obtains a reference to the GPU device this pool belongs to.
Sourcefn label(&self) -> Option<Retained<NSString>>
fn label(&self) -> Option<Retained<NSString>>
Queries the optional debug label of this resource view pool.
Sourceunsafe fn copyResourceViewsFromPool_sourceRange_destinationIndex(
&self,
source_pool: &ProtocolObject<dyn MTLResourceViewPool>,
source_range: NSRange,
destination_index: NSUInteger,
) -> MTLResourceID
Available on crate feature MTLTypes only.
unsafe fn copyResourceViewsFromPool_sourceRange_destinationIndex( &self, source_pool: &ProtocolObject<dyn MTLResourceViewPool>, source_range: NSRange, destination_index: NSUInteger, ) -> MTLResourceID
MTLTypes only.Copies a range of resource views from a source view pool to a destination location in this view pool.
-
Parameters:
-
sourcePool: resource view pool from which to copy resource views.
-
sourceRange: The range in the source resource view pool to copy.
-
destinationIndex: The starting index in this destination view pool into which to copy the source range of resource views.
-
Returns: The
MTLResourceIDof the resource view corresponding todestinationIndexof the copy in this resource view pool.
Safety
sourceRangemight not be bounds-checked.destinationIndexmight not be bounds-checked.