pub type MTL4NewMachineLearningPipelineStateCompletionHandler = *mut DynBlock<dyn Fn(*mut ProtocolObject<dyn MTL4MachineLearningPipelineState>, *mut NSError)>;Available on crate features
block2 and MTL4Compiler and MTL4MachineLearningPipeline and MTLAllocation only.Expand description
Provides a signature for a callback block that Metal calls when the compiler finishes a build task for a machine learning pipeline state.
See also Appleās documentation